# Copyright 2021 UW-IT, University of Washington
# SPDX-License-Identifier: Apache-2.0

from unittest import TestCase
from commonconf import override_settings
from uw_catalyst.dao import Catalyst_DAO
from uw_catalyst.util import fdao_catalyst_override
from restclients_core.dao import DAO
import mock


@fdao_catalyst_override
class CatalystTestDao(TestCase):
    @mock.patch.object(DAO, '_load_resource')
    def test_url(self, mock_load):
        r = Catalyst_DAO()._load_resource('GET', '/rest/v1/rest/123', {}, None)
        mock_load.assert_called_with('GET', '/rest/v1/rest/123', {}, None)

        with override_settings(
                RESTCLIENTS_CATALYST_SOL_AUTH_PRIVATE_KEY='token'):
            r = Catalyst_DAO()._load_resource(
                'GET', '/rest/v1/rest/123', {}, None)
            mock_load.assert_called_with(
                'GET', '/js_rest/v1/rest/123', {}, None)

    def test_custom_headers(self):
        headers = Catalyst_DAO()._custom_headers('GET', '/', {}, None)
        self.assertEquals(headers, None)

        with override_settings(
                RESTCLIENTS_CATALYST_SOL_AUTH_PRIVATE_KEY='token',
                RESTCLIENTS_CATALYST_SOL_AUTH_PUBLIC_KEY='testing'):

            headers = Catalyst_DAO()._custom_headers('GET', '/', {}, None)

            self.assertRegexpMatches(headers['Authorization'],
                                     r'^SolAuth testing:[a-f0-9]+$')
            self.assertRegexpMatches(headers['Date'], r'UTC')



# Copyright 2021 UW-IT, University of Washington
# SPDX-License-Identifier: Apache-2.0

from unittest import TestCase
from uw_sws.section import get_section_by_label
from uw_pws import PWS
from uw_sws.util import fdao_sws_override
from uw_pws.util import fdao_pws_override
from uw_catalyst.util import fdao_catalyst_override
from uw_catalyst.gradebook import (
    get_participants_for_gradebook, get_participants_for_section)
from uw_catalyst.exceptions import InvalidGradebookID


@fdao_sws_override
@fdao_pws_override
@fdao_catalyst_override
class CatalystTestGradebook(TestCase):
    def test_invalid_gradebook_id(self):
        self.assertRaises(
            InvalidGradebookID, get_participants_for_gradebook, None)
        self.assertRaises(
            InvalidGradebookID, get_participants_for_gradebook, '')
        self.assertRaises(
            InvalidGradebookID, get_participants_for_gradebook, 'abc')
        self.assertRaises(
            InvalidGradebookID, get_participants_for_gradebook, 00000)
        self.assertRaises(
            InvalidGradebookID, get_participants_for_gradebook, 11111111111)

    def test_participants_for_gradebook(self):
        person = PWS().get_person_by_netid('bill')

        participants = get_participants_for_gradebook(12345, person)

        self.assertEquals(len(participants), 3, "Correct participant count")

    def test_participants_for_section(self):
        section = get_section_by_label('2013,summer,CSS,161/A')
        instructor = section.meetings[0].instructors[0]

        participants = get_participants_for_section(section, instructor)

        self.assertEquals(len(participants), 3, "Correct participant count")



# Copyright 2021 UW-IT, University of Washington
# SPDX-License-Identifier: Apache-2.0

from uw_catalyst.dao import Catalyst_DAO
from uw_sws import encode_section_label
from restclients_core.exceptions import DataFailureException
import json


def get_resource(url, headers):
    """
    Issue a GET request with the given url and headers,
    and return a response in json format.
    :returns: http response with content in json
    """
    headers["Accept"] = "application/json"
    response = Catalyst_DAO().getURL(url, headers)

    if response.status != 200:
        raise DataFailureException(url, response.status, response.data)

    try:
        return json.loads(response.data)
    except ValueError as ex:
        raise DataFailureException(url, response.status, response.data)



# Copyright 2021 UW-IT, University of Washington
# SPDX-License-Identifier: Apache-2.0

from restclients_core import models


class GradebookParticipant(models.Model):
    participant_id = models.IntegerField()
    person_id = models.CharField(max_length=100)
    class_grade = models.CharField(max_length=250)
    notes = models.CharField(max_length=5000)

    def json_data(self):
        return {"participant_id": self.participant_id,
                "person_id": self.person_id,
                "class_grade": self.class_grade,
                "notes": self.notes}
